/* util.h - miscellaneous utility functions
 *
 * Copyright 2009, 2015, 2022, 2023 Petteri Hintsanen <petterih@iki.fi>
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see
 * <http://www.gnu.org/licenses/>. 
 */

#ifndef PH_FUNCS_H
#define PH_FUNCS_H

#include <stdio.h>
#include <stdlib.h>

/* memory allocation */
extern void *ph_malloc(size_t size);
extern void *ph_realloc(void *ptr, size_t size);

/* input/output */
extern char *ph_getline(FILE *stream);

/* logging and diagnostics */
extern const char *ph_program_name(void);
extern void ph_set_program_name(const char *name);
extern void ph_set_debug_level(int level);
extern void ph_set_log_level(int level);
extern void ph_dprintf(const char *fmt, ...);
extern void ph_dmprintf(unsigned int mask, const char *fmt, ...);
extern void ph_lprintf(const char *fmt, ...);
extern void ph_lmprintf(unsigned int mask, const char *fmt, ...);
extern void ph_eprintf(const char *fmt, ...);
extern void ph_feprintf(const char *fmt, ...);
extern void ph_oeprintf(const char *fmt, ...);
extern void ph_wprintf(const char *fmt, ...);

/* string handling */
extern char *ph_strscat(const char **strings, char delim);
extern char *ph_strdup(const char *s);
extern char **ph_strtok(const char *s, const char *seps,
                        const char quote);
extern int ph_strtoi(const char *s, int *l);
extern void ph_free_tokens(char **tokens);

/* numerics */
extern int ph_clamp_int(int val, int min, int max);
extern void ph_srand(unsigned int seed);
extern int ph_bernoulli(double p);

/* file and path names */
extern const char *ph_basename(const char *path);

#endif  /* PH_FUNCS_H */
